#[repr(u8)]pub enum DisableBleed {
BLEED_ENABLE = 0,
BLEED_DISABLE = 1,
}Variants
BLEED_ENABLE = 0
LDO_MEM bleed current is enabled.
BLEED_DISABLE = 1
LDO_MEM bleed current is disabled. Should be set before entering in Deep Sleep low power mode and cleared after wake up from Deep SLeep low power mode.
Implementations
Sourceimpl DisableBleed
impl DisableBleed