#[repr(u8)]pub enum Xtal32koscfailure {
NOFAIL = 0,
FAILURE = 1,
}Variants
NOFAIL = 0
No oscillation failure has been detetced since the last time this bit has been cleared.
FAILURE = 1
At least one oscillation failure has been detetced since the last time this bit has been cleared.
Implementations